@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # Copyright 2015-2017 Christoph Reiter
+#                2019 Nick Boultbee
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,7 +29,6 @@ import tempfile
 import shutil
 import functools
 
-
 # pattern -> (language, [keywords])
 XGETTEXT_CONFIG = {
     "*.py": ("Python", [
@@ -110,10 +109,6 @@ def _create_pot(potfiles_path, src_root, strict):
             if language:
                 args.append("--language=" + language)
 
-            # https://github.com/Alexpux/MINGW-packages/issues/4392
-            if os.name == "nt" and not language:
-                paths = []
-
             for kw in keywords:
                 if kw:
                     args.append("--keyword=" + kw)
@@ -126,9 +121,10 @@ def _create_pot(potfiles_path, src_root, strict):
                 _write_potfiles(src_root, potfiles_in, paths)
 
                 args = ["xgettext", "--from-code=utf-8", "--add-comments",
-                    "--files-from=" + potfiles_in, "--directory=" + src_root,
-                    "--output=" + out_path, "--force-po",
-                    "--join-existing"] + args
+                        "--files-from=" + potfiles_in,
+                        "--directory=" + src_root,
+                        "--output=" + out_path, "--force-po",
+                        "--join-existing"] + args
 
                 p = subprocess.Popen(
                     args,
@@ -136,7 +132,8 @@ def _create_pot(potfiles_path, src_root, strict):
                     universal_newlines=True)
                 stdout, stderr = p.communicate()
                 if p.returncode != 0:
-                    raise GettextError(p.returncode)
+                    raise GettextError(stderr
+                                       or ("Got error: %d" % p.returncode))
                 if strict and stderr:
                     raise GettextError(stderr)
             finally:
