@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 # Copyright 2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import re
 
@@ -19,14 +19,14 @@ class PaneConfig(object):
     * display_pattern is optional (fallback: ~#tracks)
     * patterns, tied and normal tags.
     * display patterns can have function prefixes for numerical tags.
-    * ':' has to be escaped ('\:')
+    * ':' has to be escaped ('\\:')
 
     TODO: sort pattern, filter query
     """
 
     def __init__(self, row_pattern):
         parts = re.split(r"(?<!\\):", row_pattern)
-        parts = map(lambda p: p.replace(r"\:", ":"), parts)
+        parts = list(map(lambda p: p.replace(r"\:", ":"), parts))
 
         is_numeric = lambda s: s[:2] == "~#" and "~" not in s[2:]
         is_pattern = lambda s: '<' in s
@@ -51,7 +51,7 @@ class PaneConfig(object):
             if is_numeric(cat):
 
                 def format(song):
-                    v = unicode(f_round(song(cat)))
+                    v = str(f_round(song(cat)))
                     return [(v, v)]
             else:
                 format = lambda song: song.list_separate(cat)
@@ -64,7 +64,7 @@ class PaneConfig(object):
             format_display = pd.format
         else:
             if is_numeric(disp):
-                format_display = lambda coll: unicode(f_round(coll(disp)))
+                format_display = lambda coll: str(f_round(coll(disp)))
             else:
                 format_display = lambda coll: util.escape(coll.comma(disp))
 
