@@ -1,14 +1,17 @@
-# -*- coding: utf-8 -*-
 # Copyright 2014 Jan Path
 #           2014 Christoph Reiter
+#           2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
+from quodlibet import _
 from quodlibet import config
+from quodlibet.plugins.songshelpers import any_song
 from quodlibet.qltk.getstring import GetStringDialog
 from quodlibet.qltk import Icons
 from quodlibet.qltk.ratingsmenu import ConfirmRateMultipleDialog
@@ -19,6 +22,10 @@ class ExactRating(SongsMenuPlugin):
     PLUGIN_ID = "exact-rating"
     PLUGIN_NAME = _("Set Exact Rating")
     PLUGIN_DESC = _("Allows setting the rating of songs with a number.")
+    REQUIRES_ACTION = True
+    PLUGIN_ICON = Icons.USER_BOOKMARKS
+
+    plugin_handles = any_song(lambda s: s.can_change())
 
     def plugin_songs(self, songs):
         value = -1
@@ -44,7 +51,7 @@ class ExactRating(SongsMenuPlugin):
         if (count > 1 and config.getboolean("browsers",
                 "rating_confirm_multiple")):
             confirm_dialog = ConfirmRateMultipleDialog(
-                self.plugin_window, count, value)
+                self.plugin_window, _("Change _Rating"), count, value)
             if confirm_dialog.run() != Gtk.ResponseType.YES:
                 return
 
