@@ -1,15 +1,16 @@
-# -*- coding: utf-8 -*-
 # Copyright 2009-2011 Steven Robertson, Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import collections
 import subprocess
 
 from gi.repository import GLib, Gst
 
+from quodlibet import _
 from quodlibet.util.string import decode
 from quodlibet.util import is_linux, is_windows
 from quodlibet.player import PlayerError
@@ -18,6 +19,16 @@ from quodlibet.player import PlayerError
 def pulse_is_running():
     """Returns whether pulseaudio is running"""
 
+    # If we have a pulsesink we can get the server presence through
+    # setting the ready state
+    element = Gst.ElementFactory.make("pulsesink", None)
+    if element is not None:
+        element.set_state(Gst.State.READY)
+        res = element.get_state(0)[0]
+        element.set_state(Gst.State.NULL)
+        return res != Gst.StateChangeReturn.FAILURE
+
+    # In case we don't have it call the pulseaudio binary
     try:
         subprocess.check_call(["pulseaudio", "--check"])
     except subprocess.CalledProcessError:
@@ -69,7 +80,6 @@ def find_audio_sink():
     if is_windows():
         sinks = [
             "directsoundsink",
-            "autoaudiosink",
         ]
     elif is_linux() and pulse_is_running():
         sinks = [
@@ -106,7 +116,7 @@ def GStreamerSink(pipeline_desc):
         try:
             pipe = [Gst.parse_launch(e) for e in pipeline_desc.split('!')]
         except GLib.GError as e:
-            message = e.message.decode("utf-8")
+            message = e.message
             raise PlayerError(_("Invalid GStreamer output pipeline"), message)
 
     if pipe:
@@ -134,7 +144,7 @@ class TagListWrapper(collections.Mapping):
         return self._list.n_tags()
 
     def __iter__(self):
-        for i in xrange(len(self)):
+        for i in range(len(self)):
             yield self._list.nth_tag_name(i)
 
     def __getitem__(self, key):
@@ -169,20 +179,20 @@ def parse_gstreamer_taglist(tags):
     merged = {}
     for key in tags.keys():
         value = tags[key]
-        # extended-comment sometimes containes a single vorbiscomment or
+        # extended-comment sometimes contains a single vorbiscomment or
         # a list of them ["key=value", "key=value"]
         if key == "extended-comment":
             if not isinstance(value, list):
                 value = [value]
             for val in value:
-                if not isinstance(val, unicode):
+                if not isinstance(val, str):
                     continue
                 split = val.split("=", 1)
-                sub_key = decode(split[0])
+                sub_key = split[0]
                 val = split[-1]
                 if sub_key in merged:
                     sub_val = merged[sub_key]
-                    if not isinstance(sub_val, unicode):
+                    if not isinstance(sub_val, str):
                         continue
                     if val not in sub_val.split("\n"):
                         merged[sub_key] += "\n" + val
@@ -192,15 +202,15 @@ def parse_gstreamer_taglist(tags):
             value = value.to_iso8601_string()
             merged[key] = value
         else:
-            if isinstance(value, (int, long, float)):
+            if isinstance(value, (int, float)):
                 merged[key] = value
                 continue
 
-            if isinstance(value, str):
+            if isinstance(value, bytes):
                 value = decode(value)
 
-            if not isinstance(value, unicode):
-                value = unicode(value)
+            if not isinstance(value, str):
+                value = str(value)
 
             if key in merged:
                 merged[key] += "\n" + value
