@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 # Copyright 2012 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 
 class GStreamerPlugin(object):
@@ -24,6 +24,8 @@ class GStreamerPlugin(object):
     To notify setting changes, call queue_update.
     """
 
+    PLUGIN_ICON = "audio-volume-high"
+
     _handler = None
 
     priority = 0
