@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2004-2012 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2011-2017 Nick Boultbee
 #
@@ -15,6 +14,7 @@ from quodlibet import C_, _
 from quodlibet import qltk
 from quodlibet import config
 from quodlibet import util
+from quodlibet import app
 
 from quodlibet.util import massagers
 
@@ -198,7 +198,11 @@ class SplitValues(Gtk.ImageMenuItem):
         self.set_image(Gtk.Image.new_from_icon_name(
             Icons.EDIT_FIND_REPLACE, Gtk.IconSize.MENU))
         spls = config.gettext("editing", "split_on").split()
-        self.set_sensitive(len(split_value(value, spls)) > 1)
+        vals = [val if len(val) <= 64 else val[:64] + "…"
+                for val in split_value(value, spls)]
+        string = ", ".join(["{}={}".format(tag, val) for val in vals])
+        self.set_label(string)
+        self.set_sensitive(len(vals) > 1)
 
     def activated(self, tag, value):
         spls = config.gettext("editing", "split_on").split()
@@ -215,7 +219,14 @@ class SplitDisc(Gtk.ImageMenuItem):
             label=_("Split Disc out of _Album"), use_underline=True)
         self.set_image(Gtk.Image.new_from_icon_name(
             Icons.EDIT_FIND_REPLACE, Gtk.IconSize.MENU))
-        self.set_sensitive(split_album(value)[1] is not None)
+
+        album, disc = split_album(value)
+        if disc is not None:
+            album = album if len(album) <= 64 else album[:64] + "…"
+            self.set_label("{}={}, {}={}".format(tag, album,
+                           self.needs[0], disc))
+
+        self.set_sensitive(disc is not None)
 
     def activated(self, tag, value):
         album, disc = split_album(value)
@@ -232,12 +243,24 @@ class SplitTitle(Gtk.ImageMenuItem):
             label=_("Split _Version out of Title"), use_underline=True)
         self.set_image(Gtk.Image.new_from_icon_name(
             Icons.EDIT_FIND_REPLACE, Gtk.IconSize.MENU))
-        spls = config.gettext("editing", "split_on").split()
-        self.set_sensitive(bool(split_title(value, spls)[1]))
+        tag_spls = config.gettext("editing", "split_on").split()
+        sub_spls = config.gettext("editing", "sub_split_on").split()
+
+        title, versions = split_title(value, tag_spls, sub_spls)
+        if versions:
+            title = title if len(title) <= 64 else title[:64] + "…"
+            versions = [ver if len(ver) <= 64 else ver[:64] + "…"
+                        for ver in versions]
+            string = (", ".join(["{}={}".format(tag, title)] +
+               ["{}={}".format(self.needs[0], ver) for ver in versions]))
+            self.set_label(string)
+
+        self.set_sensitive(bool(versions))
 
     def activated(self, tag, value):
-        spls = config.gettext("editing", "split_on").split()
-        title, versions = split_title(value, spls)
+        tag_spls = config.gettext("editing", "split_on").split()
+        sub_spls = config.gettext("editing", "sub_split_on").split()
+        title, versions = split_title(value, tag_spls, sub_spls)
         return [(tag, title)] + [("version", v) for v in versions]
 
 
@@ -249,12 +272,24 @@ class SplitPerson(Gtk.ImageMenuItem):
         super(SplitPerson, self).__init__(label=self.title, use_underline=True)
         self.set_image(Gtk.Image.new_from_icon_name(
             Icons.EDIT_FIND_REPLACE, Gtk.IconSize.MENU))
-        spls = config.gettext("editing", "split_on").split()
-        self.set_sensitive(bool(split_people(value, spls)[1]))
+        tag_spls = config.gettext("editing", "split_on").split()
+        sub_spls = config.gettext("editing", "sub_split_on").split()
+
+        artist, others = split_people(value, tag_spls, sub_spls)
+        if others:
+            artist = artist if len(artist) <= 64 else artist[:64] + "…"
+            others = [other if len(other) <= 64 else other[:64] + "…"
+                        for other in others]
+            string = (", ".join(["{}={}".format(tag, artist)] +
+                ["{}={}".format(self.needs[0], o) for o in others]))
+            self.set_label(string)
+
+        self.set_sensitive(bool(others))
 
     def activated(self, tag, value):
-        spls = config.gettext("editing", "split_on").split()
-        artist, others = split_people(value, spls)
+        tag_spls = config.gettext("editing", "split_on").split()
+        sub_spls = config.gettext("editing", "sub_split_on").split()
+        artist, others = split_people(value, tag_spls, sub_spls)
         return [(tag, artist)] + [(self.needs[0], o) for o in others]
 
 
@@ -617,6 +652,8 @@ class EditTags(Gtk.VBox):
             comment = entry.value
             text = comment.text
 
+            split_menu = Gtk.Menu()
+
             for Item in items:
                 if Item.tags and entry.tag not in Item.tags:
                     continue
@@ -634,10 +671,36 @@ class EditTags(Gtk.VBox):
                             or comment.is_special()):
                         b.set_sensitive(False)
 
-                    menu.append(b)
+                    vals = b.activated(entry.tag, text)
+                    if len(vals) > 1 and vals[1][1]:
+                        split_menu.append(b)
 
-            if menu.get_children():
-                menu.append(SeparatorMenuItem())
+            if split_menu.get_children():
+                split_menu.append(SeparatorMenuItem())
+
+            pref_item = MenuItem(_("_Configure"), Icons.PREFERENCES_SYSTEM)
+            split_menu.append(pref_item)
+
+            def show_prefs(parent):
+                from quodlibet.qltk.exfalsowindow import ExFalsoWindow
+                if isinstance(app.window, ExFalsoWindow):
+                    from quodlibet.qltk.exfalsowindow import PreferencesWindow
+                    window = PreferencesWindow(parent)
+                else:
+                    from quodlibet.qltk.prefs import PreferencesWindow
+                    window = PreferencesWindow(parent, open_page="tagging")
+                window.show()
+
+            connect_obj(pref_item, "activate", show_prefs, self)
+
+            split_item = MenuItem(_("_Split Tag"), Icons.EDIT_FIND_REPLACE)
+
+            if split_menu.get_children():
+                split_item.set_submenu(split_menu)
+            else:
+                split_item.set_sensitive(False)
+
+            menu.append(split_item)
 
         copy_b = MenuItem(_("_Copy Value(s)"), Icons.EDIT_COPY)
         copy_b.connect('activate', self.__copy_tag_value, view)
