@@ -1,20 +1,19 @@
-# -*- coding: utf-8 -*-
 # Copyright 2005 Joe Wreschnig, Michael Urman
 #           2011, 2012 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 import math
 
 from gi.repository import Gtk, GObject, Gdk, Gio, Pango
 
+from quodlibet import _
 from quodlibet.qltk import is_accel, add_fake_accel
 from quodlibet.qltk.x import SeparatorMenuItem, MenuItem
 from quodlibet.qltk import Icons
-from quodlibet.util import gdecode
-from quodlibet.query import Query, QueryType
 
 
 class EditableUndo(object):
@@ -95,7 +94,7 @@ class EditableUndo(object):
             menu.prepend(item)
 
     def __all(self):
-        text = gdecode(self.get_chars(0, -1))
+        text = self.get_chars(0, -1)
         pos = self.get_position()
         return [text, pos]
 
@@ -222,7 +221,13 @@ class ClearEntryMixin(object):
         self.set_icon_from_gicon(Gtk.EntryIconPosition.SECONDARY, gicon)
         self.connect("icon-release", self.__clear)
 
+    def clear(self):
+        self.__do_clear()
+
     def __clear(self, button, *args):
+        self.__do_clear()
+
+    def __do_clear(self):
         # TODO: don't change the order.. we connect to clear and remove all
         # timeouts added for text change in the searchbar
         self.delete_text(0, -1)
@@ -247,12 +252,12 @@ class ValidatingEntryMixin(object):
             self.connect('changed', self.__color, validator)
 
     def __color(self, widget, validator):
-        value = validator(gdecode(self.get_text()))
+        value = validator(self.get_text())
         if value is True:
             color = self.VALID
         elif value is False:
             color = self.INVALID
-        elif value and isinstance(value, basestring):
+        elif value and isinstance(value, str):
             color = Gdk.RGBA()
             color.parse(value)
         else:
@@ -264,20 +269,6 @@ class ValidatingEntryMixin(object):
             self.override_color(Gtk.StateType.NORMAL, None)
 
 
-def QueryValidator(string):
-    """Returns True/False for a query, None for a text only query"""
-
-    type_ = Query.get_type(string)
-    if type_ == QueryType.VALID:
-        # in case of an empty but valid query we say it's "text"
-        if Query.match_all(string):
-            return None
-        return True
-    elif type_ == QueryType.INVALID:
-        return False
-    return None
-
-
 class ValidatingEntry(ClearEntry, ValidatingEntryMixin):
     def __init__(self, validator=None, *args):
         super(ValidatingEntry, self).__init__(*args)
