@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2012 Christoph Reiter
 #           2012-2017 Nick Boultbee
@@ -1111,6 +1110,8 @@ class QuodLibetWindow(Window, PersistentWindowMixin, AppWindow):
             self.browser.restore()
             self.browser.activate()
         self.browser.finalize(restore)
+        if not restore:
+            self.browser.unfilter()
         if self.browser.can_reorder:
             self.songlist.enable_drop()
         elif self.browser.dropped:
