@@ -1,18 +1,19 @@
 # Copyright 2006 Joe Wreschnig
+#           2015 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
 from quodlibet.util import tag
-
-import quodlibet.formats
+from quodlibet.util.tags import USER_TAGS
 
 
 class _TagsCombo(object):
-    __tags = sorted(quodlibet.formats.USEFUL_TAGS)
+    __tags = sorted(USER_TAGS)
 
     def _fill_model(self, can_change):
         self.clear()
@@ -32,9 +33,9 @@ class _TagsCombo(object):
         if len(model) == 0:
             raise ValueError("TagsCombo boxes require at least one tag name")
 
-    def __tag(self):
+    @property
+    def tag(self):
         return self._tag()
-    tag = property(__tag)
 
 
 class TagsComboBox(Gtk.ComboBox, _TagsCombo):
@@ -60,12 +61,14 @@ class TagsComboBoxEntry(Gtk.ComboBox, _TagsCombo):
 
     The 'tag' attribute is the currently chosen tag."""
 
-    def __init__(self, can_change=None):
+    def __init__(self, can_change=None, tooltip_markup=None):
         super(TagsComboBoxEntry, self).__init__(
             model=Gtk.ListStore(str, str),
             entry_text_column=0,
             has_entry=True)
         self._fill_model(can_change)
+        if tooltip_markup:
+            self.get_child().set_tooltip_markup(tooltip_markup)
 
     def _fill_model(self, can_change):
         super(TagsComboBoxEntry, self)._fill_model(can_change)
