@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -75,7 +74,9 @@ class TCommands(TestCase):
         self.__send("random album")
         self.__send("refresh")
         self.__send("repeat 0")
-        self.__send("set-rating 0.5")
+        self.__send("rating 0.5")
+        self.__send("rating +0.01")
+        self.__send("rating -10")
         self.__send("show-window")
         self.__send("song-list 1")
         self.__send("stop-after 1")
