@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -10,7 +9,7 @@ import os
 import sys
 
 from quodlibet import config
-from quodlibet.util import is_linux
+from quodlibet.util import is_linux, is_flatpak
 from quodlibet.util.trash import use_trash, trash
 from tests import TestCase, mkstemp, skipUnless
 
@@ -48,7 +47,8 @@ class Ttrash(TestCase):
         try:
             os.name = 'posix'
             sys.platform = 'linux'
-            self.assertTrue(use_trash())
+            if not is_flatpak():
+                self.assertTrue(use_trash())
         finally:
             os.name = old_os_name
             sys.platform = old_sys_platform
